If you use SNCosmo for work presented in a publication, you can include a citation to the code. See https://doi.org/10.5281/zenodo.592747 for citation styles.

A BibTeX entry for LaTeX users is:
```
@article{Barbary:11938,
      author        = "Barbary, Kyle",
      title         = "{sncosmo}",
      month         = "Apr",
      year          = "2014",
      doi           = "{10.5281/zenodo.592747}",
      url           = "{https://doi.org/10.5281/zenodo.592747}",
}
```
